pub struct ClaimCommand {
pub acquisition: AcquireCommand,
pub dispatch: DispatchRef,
}Expand description
The session, consumer, and sequence identify one claim operation. Its exact dispatch binding is immutable even if the exchange outcome is unknown.
Fields
acquisition: AcquireCommanddispatch: DispatchRefImplementations